@@ -29,11 +29,11 @@ qfun = function(a,b,Sigma)
   for(i in 1:n){
     if(a[i] != -Inf){
       qa[i] = log2prod0(dnorm(x = a[i],mean = 0,sd = s[i]),
-                        pmvn.genz(lower = a[-i],upper = b[-i],mean = Sigma[-i,i]/Sigma[i,i]*a[i],sigma = Sigma[-i,-i] - (Sigma[-i,i]/Sigma[i,i])%*%t(Sigma[i,-i]),uselog2 = TRUE)$Estimation)
+                        prob_opt(lower = a[-i],upper = b[-i],mean = Sigma[-i,i]/Sigma[i,i]*a[i],sigma = Sigma[-i,-i] - (Sigma[-i,i]/Sigma[i,i])%*%t(Sigma[i,-i]),uselog2 = TRUE))
     }
     if(b[i] != Inf){
       qb[i] = log2prod0(dnorm(x = b[i],mean = 0,sd = s[i]),
-                        pmvn.genz(lower = a[-i],upper = b[-i],mean = Sigma[-i,i]/Sigma[i,i]*b[i],sigma = Sigma[-i,-i] - (Sigma[-i,i]/Sigma[i,i])%*%t(Sigma[i,-i]),uselog2 = TRUE)$Estimation)
+                        prob_opt(lower = a[-i],upper = b[-i],mean = Sigma[-i,i]/Sigma[i,i]*b[i],sigma = Sigma[-i,-i] - (Sigma[-i,i]/Sigma[i,i])%*%t(Sigma[i,-i]),uselog2 = TRUE))
     }
   }
   return(list(qa = qa,qb = qb))
@@ -63,7 +63,7 @@ qfun_b = function(b1,Sigma)
   for(i in 1:p){
     if(b1[i] != Inf){
       qb[i] = log2prod0(dnorm(x = b1[i],mean = 0,sd = s[i]),
-                        pmvn.genz(upper = b1[-i],mean = Sigma[-i,i]/Sigma[i,i]*b1[i],sigma = Sigma[-i,-i] - (Sigma[-i,i]/Sigma[i,i])%*%t(Sigma[i,-i]),uselog2 = TRUE)$Estimation)
+                        prob_opt(upper = b1[-i],mean = Sigma[-i,i]/Sigma[i,i]*b1[i],sigma = Sigma[-i,-i] - (Sigma[-i,i]/Sigma[i,i])%*%t(Sigma[i,-i]),uselog2 = TRUE))
     }
   }
   return(qb)
@@ -92,9 +92,9 @@ qfun.noinf = function(a,b,Sigma)
   qa = qb = rep(0,n)
   for(i in 1:n){
     qa[i] = log2prod0(dnorm(x = a[i],mean = 0,sd = s[i]),
-                      pmvn.genz(lower = a[-i],upper = b[-i],mean = Sigma[-i,i]/Sigma[i,i]*a[i],sigma = Sigma[-i,-i] - (Sigma[-i,i]/Sigma[i,i])%*%t(Sigma[i,-i]),uselog2 = TRUE)$Estimation)
+                      prob_opt(lower = a[-i],upper = b[-i],mean = Sigma[-i,i]/Sigma[i,i]*a[i],sigma = Sigma[-i,-i] - (Sigma[-i,i]/Sigma[i,i])%*%t(Sigma[i,-i]),uselog2 = TRUE))
     qb[i] = log2prod0(dnorm(x = b[i],mean = 0,sd = s[i]),
-                      pmvn.genz(lower = a[-i],upper = b[-i],mean = Sigma[-i,i]/Sigma[i,i]*b[i],sigma = Sigma[-i,-i] - (Sigma[-i,i]/Sigma[i,i])%*%t(Sigma[i,-i]),uselog2 = TRUE)$Estimation)
+                      prob_opt(lower = a[-i],upper = b[-i],mean = Sigma[-i,i]/Sigma[i,i]*b[i],sigma = Sigma[-i,-i] - (Sigma[-i,i]/Sigma[i,i])%*%t(Sigma[i,-i]),uselog2 = TRUE))
   }
   return(list(qa = qa,qb = qb))
 }
